@@ -631,7 +631,11 @@ class CallableTest:
                     msg = f"Verifying expected output for {fun_name} " \
                           f"against {input_list[0]}..."
                     _logger.info(msg)
-                    assert callable_test_config.expected_output == ans, msg
+                    expected = callable_test_config.expected_output
+                    if expected != ans:
+                        msg = f'Actual output differs from expectation. ' \
+                              f'Actual: {ans}. Expected: {expected}.'
+                        raise ValueError(msg)
                 else:
                     _logger.info("No output verification for %s",
                                  fun_name)
